from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Gauss:
	"""Gauss commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("gauss", core, parent)

	def get_bandwidth(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:POWer:FILTer:GAUSs:BWIDth \n
		Snippet: value: float = driver.configure.gprfMeasurement.power.filterPy.gauss.get_bandwidth() \n
		Selects the bandwidth for the Gaussian filter. \n
			:return: gauss_bw: You can enter values between 10 Hz and 10 MHz. The setting is rounded to the closest of the following values: 10 / 30 / 50 / 100 / 300 / 500 Hz 1 / 3 / 5 / 6.25 / 10 / 30 / 50 / 100 / 300 / 500 kHz 1 / 3 / 5 / 10 MHz Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:POWer:FILTer:GAUSs:BWIDth?')
		return Conversions.str_to_float(response)

	def set_bandwidth(self, gauss_bw: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:POWer:FILTer:GAUSs:BWIDth \n
		Snippet: driver.configure.gprfMeasurement.power.filterPy.gauss.set_bandwidth(gauss_bw = 1.0) \n
		Selects the bandwidth for the Gaussian filter. \n
			:param gauss_bw: You can enter values between 10 Hz and 10 MHz. The setting is rounded to the closest of the following values: 10 / 30 / 50 / 100 / 300 / 500 Hz 1 / 3 / 5 / 6.25 / 10 / 30 / 50 / 100 / 300 / 500 kHz 1 / 3 / 5 / 10 MHz Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(gauss_bw)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:POWer:FILTer:GAUSs:BWIDth {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Condition:
	"""Condition commands group definition. 5 total commands, 5 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("condition", core, parent)

	@property
	def off(self):
		"""off commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_off'):
			from .Condition_.Off import Off
			self._off = Off(self._core, self._base)
		return self._off

	@property
	def qued(self):
		"""qued commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_qued'):
			from .Condition_.Qued import Qued
			self._qued = Qued(self._core, self._base)
		return self._qued

	@property
	def run(self):
		"""run commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_run'):
			from .Condition_.Run import Run
			self._run = Run(self._core, self._base)
		return self._run

	@property
	def rdy(self):
		"""rdy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rdy'):
			from .Condition_.Rdy import Rdy
			self._rdy = Rdy(self._core, self._base)
		return self._rdy

	@property
	def sdReached(self):
		"""sdReached commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sdReached'):
			from .Condition_.SdReached import SdReached
			self._sdReached = SdReached(self._core, self._base)
		return self._sdReached

	def clone(self) -> 'Condition':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Condition(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Voip:
	"""Voip commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("voip", core, parent)

	# noinspection PyTypeChecker
	class LevelStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: No parameter help available
			- Upper: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Upper: float = None

	def get_level(self) -> LevelStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:TSENsitivity:VOIP:LEVel \n
		Snippet: value: LevelStruct = driver.configure.afRf.measurement.searchRoutines.limit.tsensitivity.voip.get_level() \n
		No command help available \n
			:return: structure: for return value, see the help for LevelStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:TSENsitivity:VOIP:LEVel?', self.__class__.LevelStruct())

	def set_level(self, value: LevelStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:TSENsitivity:VOIP:LEVel \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.limit.tsensitivity.voip.set_level(value = LevelStruct()) \n
		No command help available \n
			:param value: see the help for LevelStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:TSENsitivity:VOIP:LEVel', value)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tones:
	"""Tones commands group definition. 34 total commands, 11 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tones", core, parent)

	@property
	def voip(self):
		"""voip commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_voip'):
			from .Tones_.Voip import Voip
			self._voip = Voip(self._core, self._base)
		return self._voip

	@property
	def spdifRight(self):
		"""spdifRight commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_spdifRight'):
			from .Tones_.SpdifRight import SpdifRight
			self._spdifRight = SpdifRight(self._core, self._base)
		return self._spdifRight

	@property
	def spdifLeft(self):
		"""spdifLeft commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_spdifLeft'):
			from .Tones_.SpdifLeft import SpdifLeft
			self._spdifLeft = SpdifLeft(self._core, self._base)
		return self._spdifLeft

	@property
	def audioInput(self):
		"""audioInput commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_audioInput'):
			from .Tones_.AudioInput import AudioInput
			self._audioInput = AudioInput(self._core, self._base)
		return self._audioInput

	@property
	def demodulation(self):
		"""demodulation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_demodulation'):
			from .Tones_.Demodulation import Demodulation
			self._demodulation = Demodulation(self._core, self._base)
		return self._demodulation

	@property
	def dcs(self):
		"""dcs commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_dcs'):
			from .Tones_.Dcs import Dcs
			self._dcs = Dcs(self._core, self._base)
		return self._dcs

	@property
	def dialing(self):
		"""dialing commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_dialing'):
			from .Tones_.Dialing import Dialing
			self._dialing = Dialing(self._core, self._base)
		return self._dialing

	@property
	def selCall(self):
		"""selCall commands group. 2 Sub-classes, 4 commands."""
		if not hasattr(self, '_selCall'):
			from .Tones_.SelCall import SelCall
			self._selCall = SelCall(self._core, self._base)
		return self._selCall

	@property
	def fdialing(self):
		"""fdialing commands group. 1 Sub-classes, 5 commands."""
		if not hasattr(self, '_fdialing'):
			from .Tones_.Fdialing import Fdialing
			self._fdialing = Fdialing(self._core, self._base)
		return self._fdialing

	@property
	def dtmf(self):
		"""dtmf commands group. 2 Sub-classes, 2 commands."""
		if not hasattr(self, '_dtmf'):
			from .Tones_.Dtmf import Dtmf
			self._dtmf = Dtmf(self._core, self._base)
		return self._dtmf

	@property
	def scal(self):
		"""scal commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_scal'):
			from .Tones_.Scal import Scal
			self._scal = Scal(self._core, self._base)
		return self._scal

	def clone(self) -> 'Tones':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tones(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Syntax:
	"""Syntax commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("syntax", core, parent)

	def get(self, header: str) -> bytes:
		"""SCPI: SYSTem:HELP:SYNTax \n
		Snippet: value: bytes = driver.system.help.syntax.get(header = '1') \n
		No command help available \n
			:param header: No help available
			:return: syntax: No help available"""
		param = Conversions.value_to_quoted_str(header)
		response = self._core.io.query_bin_block_ERROR(f'SYSTem:HELP:SYNTax? {param}')
		return response

	def get_all(self) -> bytes:
		"""SCPI: SYSTem:HELP:SYNTax:ALL \n
		Snippet: value: bytes = driver.system.help.syntax.get_all() \n
		No command help available \n
			:return: syntax: No help available
		"""
		response = self._core.io.query_bin_block('SYSTem:HELP:SYNTax:ALL?')
		return response



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.ArgSingleSuppressed import ArgSingleSuppressed
from ......Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FreqError:
	"""FreqError commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("freqError", core, parent)

	def fetch(self) -> int:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:FREQuency:COUNter:FERRor \n
		Snippet: value: int = driver.afRf.measurement.frequency.counter.freqError.fetch() \n
		Queries the frequency error determined by the search procedure. The error is calculated as counted frequency minus
		configured analyzer frequency. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: frequency_error: Range: -3 GHz to 3 GHz, Unit: Hz"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_str_suppressed(f'FETCh:AFRF:MEASurement<Instance>:FREQuency:COUNter:FERRor?', suppressed)
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Symbols:
	"""Symbols commands group definition. 4 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("symbols", core, parent)

	@property
	def hexadecimal(self):
		"""hexadecimal commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_hexadecimal'):
			from .Symbols_.Hexadecimal import Hexadecimal
			self._hexadecimal = Hexadecimal(self._core, self._base)
		return self._hexadecimal

	@property
	def binary(self):
		"""binary commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_binary'):
			from .Symbols_.Binary import Binary
			self._binary = Binary(self._core, self._base)
		return self._binary

	def clone(self) -> 'Symbols':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Symbols(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.StructBase import StructBase
from ...Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Error:
	"""Error commands group definition. 5 total commands, 1 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("error", core, parent)

	@property
	def code(self):
		"""code commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_code'):
			from .Error_.Code import Code
			self._code = Code(self._core, self._base)
		return self._code

	# noinspection PyTypeChecker
	class AllStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Error_Number: int: 0 means that the queue is empty. Positive error codes are instrument-dependent. Negative error codes are reserved by the SCPI standard.
			- Error_Text: str: String specifying the error"""
		__meta_args_list = [
			ArgStruct.scalar_int('Error_Number'),
			ArgStruct.scalar_str('Error_Text')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Error_Number: int = None
			self.Error_Text: str = None

	def get_all(self) -> AllStruct:
		"""SCPI: SYSTem:ERRor:ALL \n
		Snippet: value: AllStruct = driver.system.error.get_all() \n
		Queries and deletes all entries in the error queue. Each entry consists of an error code and a short description of the
		error. The entries are returned as comma-separated list: {<ErrorNumber>, <ErrorText>}entry 1, {<ErrorNumber>,
		<ErrorText>}entry 2, ..., {<ErrorNumber>, <ErrorText>}entry n \n
			:return: structure: for return value, see the help for AllStruct structure arguments.
		"""
		return self._core.io.query_struct('SYSTem:ERRor:ALL?', self.__class__.AllStruct())

	def get_count(self) -> int:
		"""SCPI: SYSTem:ERRor:COUNt \n
		Snippet: value: int = driver.system.error.get_count() \n
		Queries the number of entries in the error queue. \n
			:return: error_count: Number of entries Range: 0 to n
		"""
		response = self._core.io.query_str('SYSTem:ERRor:COUNt?')
		return Conversions.str_to_int(response)

	# noinspection PyTypeChecker
	class NextStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Error_Code: int: 0 means that the queue is empty. Positive error codes are instrument-dependent. Negative error codes are reserved by the SCPI standard.
			- Error_Description: str: String specifying the error"""
		__meta_args_list = [
			ArgStruct.scalar_int('Error_Code'),
			ArgStruct.scalar_str('Error_Description')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Error_Code: int = None
			self.Error_Description: str = None

	def get_next(self) -> NextStruct:
		"""SCPI: SYSTem:ERRor[:NEXT] \n
		Snippet: value: NextStruct = driver.system.error.get_next() \n
		Queries and deletes the oldest entry in the error queue. \n
			:return: structure: for return value, see the help for NextStruct structure arguments.
		"""
		return self._core.io.query_struct('SYSTem:ERRor:NEXT?', self.__class__.NextStruct())

	def clone(self) -> 'Error':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Error(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)

	def reset(self) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:FREQuency:RESet \n
		Snippet: driver.source.afRf.generator.dialing.selCall.frequency.reset() \n
		No command help available \n
		"""
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:FREQuency:RESet')

	def reset_with_opc(self) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:FREQuency:RESet \n
		Snippet: driver.source.afRf.generator.dialing.selCall.frequency.reset_with_opc() \n
		No command help available \n
		Same as reset, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:FREQuency:RESet')

	def set(self, standard: enums.SelCallStandard, frequency: List[float]) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:FREQuency \n
		Snippet: driver.source.afRf.generator.dialing.selCall.frequency.set(standard = enums.SelCallStandard.CCIR, frequency = [1.1, 2.2, 3.3]) \n
		Configures the user-defined tone table for a SelCall standard. To enable the table, see method RsCma.Source.AfRf.
		Generator.Dialing.SelCall.UserDefined.enable. \n
			:param standard: CCIR | EEA | EIA | ZVEI1 | ZVEI2 | ZVEI3 | DZVei | PZVei Selects the SelCall standard
			:param frequency: Comma-separated list of up to 16 frequencies, for digit 0 to F You can specify fewer than 16 values to configure only the beginning of the tone table. The *RST values and ranges depend on the SelCall standard and on the digit. The ranges are approximately: default frequency minus 5% to default frequency plus 5%. Unit: Hz
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('standard', standard, DataType.Enum), ArgSingle.as_open_list('frequency', frequency, DataType.FloatList))
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:FREQuency {param}'.rstrip())

	def get(self, standard: enums.SelCallStandard) -> List[float]:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:FREQuency \n
		Snippet: value: List[float] = driver.source.afRf.generator.dialing.selCall.frequency.get(standard = enums.SelCallStandard.CCIR) \n
		Configures the user-defined tone table for a SelCall standard. To enable the table, see method RsCma.Source.AfRf.
		Generator.Dialing.SelCall.UserDefined.enable. \n
			:param standard: CCIR | EEA | EIA | ZVEI1 | ZVEI2 | ZVEI3 | DZVei | PZVei Selects the SelCall standard
			:return: frequency: Comma-separated list of up to 16 frequencies, for digit 0 to F You can specify fewer than 16 values to configure only the beginning of the tone table. The *RST values and ranges depend on the SelCall standard and on the digit. The ranges are approximately: default frequency minus 5% to default frequency plus 5%. Unit: Hz"""
		param = Conversions.enum_scalar_to_str(standard, enums.SelCallStandard)
		response = self._core.io.query_bin_or_ascii_float_list(f'SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:FREQuency? {param}')
		return response



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sdistribute:
	"""Sdistribute commands group definition. 3 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sdistribute", core, parent)

	@property
	def current(self):
		"""current commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_current'):
			from .Sdistribute_.Current import Current
			self._current = Current(self._core, self._base)
		return self._current

	@property
	def xvalues(self):
		"""xvalues commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_xvalues'):
			from .Sdistribute_.Xvalues import Xvalues
			self._xvalues = Xvalues(self._core, self._base)
		return self._xvalues

	def clone(self) -> 'Sdistribute':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Sdistribute(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RobustAuto:
	"""RobustAuto commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("robustAuto", core, parent)

	def set(self, automatic_mode: bool, audioInput=repcap.AudioInput.Default) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:FILTer:ROBustauto \n
		Snippet: driver.configure.afRf.measurement.audioInput.filterPy.robustAuto.set(automatic_mode = False, audioInput = repcap.AudioInput.Default) \n
		Enables or disables robust automatic mode for distortion signal filtering in the AF input path. \n
			:param automatic_mode: OFF | ON
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')"""
		param = Conversions.bool_to_str(automatic_mode)
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:FILTer:ROBustauto {param}')

	def get(self, audioInput=repcap.AudioInput.Default) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:FILTer:ROBustauto \n
		Snippet: value: bool = driver.configure.afRf.measurement.audioInput.filterPy.robustAuto.get(audioInput = repcap.AudioInput.Default) \n
		Enables or disables robust automatic mode for distortion signal filtering in the AF input path. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: automatic_mode: OFF | ON"""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		response = self._core.io.query_str(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:FILTer:ROBustauto?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("enable", core, parent)

	def get(self, internalGen=repcap.InternalGen.Default) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:ENABle \n
		Snippet: value: bool = driver.source.afRf.generator.internalGenerator.enable.get(internalGen = repcap.InternalGen.Default) \n
		Queries whether an internal audio generator is assigned to an audio output path. \n
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')
			:return: enable: OFF | ON OFF Generator disabled / not assigned to an output path ON Generator enabled / assigned to an output path"""
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		response = self._core.io.query_str(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:ENABle?')
		return Conversions.str_to_bool(response)



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Types import DataType
from ...Internal.StructBase import StructBase
from ...Internal.ArgStruct import ArgStruct
from ...Internal.ArgSingleList import ArgSingleList
from ...Internal.ArgSingle import ArgSingle
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Catalog:
	"""Catalog commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("catalog", core, parent)

	@property
	def length(self):
		"""length commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_length'):
			from .Catalog_.Length import Length
			self._length = Length(self._core, self._base)
		return self._length

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Used_Memory: int: No parameter help available
			- Free_Memory: int: No parameter help available
			- File_Entry: List[str]: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Used_Memory'),
			ArgStruct.scalar_int('Free_Memory'),
			ArgStruct('File_Entry', DataType.StringList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Used_Memory: int = None
			self.Free_Memory: int = None
			self.File_Entry: List[str] = None

	def get(self, path_name: str, format_py: enums.CatalogFormat = None) -> GetStruct:
		"""SCPI: MMEMory:CATalog \n
		Snippet: value: GetStruct = driver.massMemory.catalog.get(path_name = '1', format_py = enums.CatalogFormat.ALL) \n
		Returns information about the specified directory. \n
			:param path_name: No help available
			:param format_py: ALL | WTIme ALL Output enhanced with date, time and file attributes WTIme Output enhanced with date and time
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('path_name', path_name, DataType.String), ArgSingle('format_py', format_py, DataType.Enum, True))
		return self._core.io.query_struct(f'MMEMory:CATalog? {param}'.rstrip(), self.__class__.GetStruct())

	def clone(self) -> 'Catalog':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Catalog(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



"""RsCma instrument driver
	:version: 1.7.10.24
	:copyright: 2021 by Rohde & Schwarz GMBH & Co. KG
	:license: MIT, see LICENSE for more details.
"""

__version__ = '1.7.10.24'

# Main class
from RsCma.RsCma import RsCma

# Bin data format
from RsCma.Internal.Conversions import BinIntFormat, BinFloatFormat

# Exceptions
from RsCma.Internal.InstrumentErrors import RsInstrException, TimeoutException, StatusException, UnexpectedResponseException, ResourceError, DriverValueError

# Callback Event Argument prototypes
from RsCma.Internal.IoTransferEventArgs import IoTransferEventArgs

# enums
from RsCma import enums

# repcaps
from RsCma import repcap

# Reliability interface
from RsCma.CustomFiles.reliability import Reliability, ReliabilityEventArgs, codes_table



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.Utilities import trim_str_response
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Device:
	"""Device commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("device", core, parent)

	def get_id(self) -> str:
		"""SCPI: SYSTem:BASE:DEVice:ID \n
		Snippet: value: str = driver.system.base.device.get_id() \n
		No command help available \n
			:return: device_id: No help available
		"""
		response = self._core.io.query_str('SYSTem:BASE:DEVice:ID?')
		return trim_str_response(response)

	# noinspection PyTypeChecker
	class LicenseStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Sw_Option: List[str]: No parameter help available
			- License_Count: List[int]: No parameter help available
			- Instrument: List[int]: No parameter help available"""
		__meta_args_list = [
			ArgStruct('Sw_Option', DataType.StringList, None, False, True, 1),
			ArgStruct('License_Count', DataType.IntegerList, None, False, True, 1),
			ArgStruct('Instrument', DataType.IntegerList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Sw_Option: List[str] = None
			self.License_Count: List[int] = None
			self.Instrument: List[int] = None

	def get_license(self) -> LicenseStruct:
		"""SCPI: SYSTem:BASE:DEVice:LICense \n
		Snippet: value: LicenseStruct = driver.system.base.device.get_license() \n
		No command help available \n
			:return: structure: for return value, see the help for LicenseStruct structure arguments.
		"""
		return self._core.io.query_struct('SYSTem:BASE:DEVice:LICense?', self.__class__.LicenseStruct())

	def set_license(self, value: LicenseStruct) -> None:
		"""SCPI: SYSTem:BASE:DEVice:LICense \n
		Snippet: driver.system.base.device.set_license(value = LicenseStruct()) \n
		No command help available \n
			:param value: see the help for LicenseStruct structure arguments.
		"""
		self._core.io.write_struct('SYSTem:BASE:DEVice:LICense', value)

	# noinspection PyTypeChecker
	class SetupStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Absolute_Item_Name: List[str]: No parameter help available
			- Instrument: List[int]: No parameter help available"""
		__meta_args_list = [
			ArgStruct('Absolute_Item_Name', DataType.StringList, None, False, True, 1),
			ArgStruct('Instrument', DataType.IntegerList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Absolute_Item_Name: List[str] = None
			self.Instrument: List[int] = None

	def get_setup(self) -> SetupStruct:
		"""SCPI: SYSTem:BASE:DEVice:SETup \n
		Snippet: value: SetupStruct = driver.system.base.device.get_setup() \n
		No command help available \n
			:return: structure: for return value, see the help for SetupStruct structure arguments.
		"""
		return self._core.io.query_struct('SYSTem:BASE:DEVice:SETup?', self.__class__.SetupStruct())

	def set_setup(self, value: SetupStruct) -> None:
		"""SCPI: SYSTem:BASE:DEVice:SETup \n
		Snippet: driver.system.base.device.set_setup(value = SetupStruct()) \n
		No command help available \n
			:param value: see the help for SetupStruct structure arguments.
		"""
		self._core.io.write_struct('SYSTem:BASE:DEVice:SETup', value)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Deviation:
	"""Deviation commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("deviation", core, parent)

	# noinspection PyTypeChecker
	class CalculateStruct(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Freq_Error: enums.ResultStatus: Carrier frequency error Unit: Hz
			- Power_Rms: enums.ResultStatus: Absolute RMS power of the RF signal Unit: dBm
			- Power_Pep: float: Absolute peak envelope power of the RF signal Unit: dBm"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_enum('Freq_Error', enums.ResultStatus),
			ArgStruct.scalar_enum('Power_Rms', enums.ResultStatus),
			ArgStruct.scalar_float('Power_Pep')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Freq_Error: enums.ResultStatus = None
			self.Power_Rms: enums.ResultStatus = None
			self.Power_Pep: float = None

	def calculate(self) -> CalculateStruct:
		"""SCPI: CALCulate:AFRF:MEASurement<Instance>:MEValuation:RFCarrier:DEViation \n
		Snippet: value: CalculateStruct = driver.afRf.measurement.multiEval.rfCarrier.deviation.calculate() \n
		Queries the RF carrier measurement results. CALCulate commands return error indicators instead of measurement values. \n
			:return: structure: for return value, see the help for CalculateStruct structure arguments."""
		return self._core.io.query_struct(f'CALCulate:AFRF:MEASurement<Instance>:MEValuation:RFCarrier:DEViation?', self.__class__.CalculateStruct())

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Freq_Error: float: Carrier frequency error Unit: Hz
			- Power_Rms: float: Absolute RMS power of the RF signal Unit: dBm
			- Power_Pep: float: Absolute peak envelope power of the RF signal Unit: dBm"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Freq_Error'),
			ArgStruct.scalar_float('Power_Rms'),
			ArgStruct.scalar_float('Power_Pep')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Freq_Error: float = None
			self.Power_Rms: float = None
			self.Power_Pep: float = None

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:RFCarrier:DEViation \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.rfCarrier.deviation.fetch() \n
		Queries the RF carrier measurement results. CALCulate commands return error indicators instead of measurement values. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:RFCarrier:DEViation?', self.__class__.ResultData())

	def read(self) -> ResultData:
		"""SCPI: READ:AFRF:MEASurement<Instance>:MEValuation:RFCarrier:DEViation \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.rfCarrier.deviation.read() \n
		Queries the RF carrier measurement results. CALCulate commands return error indicators instead of measurement values. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:AFRF:MEASurement<Instance>:MEValuation:RFCarrier:DEViation?', self.__class__.ResultData())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.ArgSingleSuppressed import ArgSingleSuppressed
from ......Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Maximum:
	"""Maximum commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("maximum", core, parent)

	def fetch(self) -> float:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:SROutines:SSNR:MAXimum \n
		Snippet: value: float = driver.afRf.measurement.searchRoutines.ssnr.maximum.fetch() \n
		Fetches the SNR result value for switched SNR measurement. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: ssnr: Unit: dB"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_str_suppressed(f'FETCh:AFRF:MEASurement<Instance>:SROutines:SSNR:MAXimum?', suppressed)
		return Conversions.str_to_float(response)

	def read(self) -> float:
		"""SCPI: READ:AFRF:MEASurement<Instance>:SROutines:SSNR:MAXimum \n
		Snippet: value: float = driver.afRf.measurement.searchRoutines.ssnr.maximum.read() \n
		No command help available \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: ssnr: No help available"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_str_suppressed(f'READ:AFRF:MEASurement<Instance>:SROutines:SSNR:MAXimum?', suppressed)
		return Conversions.str_to_float(response)



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Types import DataType
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tplan:
	"""Tplan commands group definition. 4 total commands, 2 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tplan", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .Tplan_.State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def estatus(self):
		"""estatus commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_estatus'):
			from .Tplan_.Estatus import Estatus
			self._estatus = Estatus(self._core, self._base)
		return self._estatus

	def get_list_py(self) -> List[str]:
		"""SCPI: SENSe:SEQuencer:TPLan:LIST \n
		Snippet: value: List[str] = driver.sense.sequencer.tplan.get_list_py() \n
		No command help available \n
			:return: tp_list: No help available
		"""
		response = self._core.io.query_str('SENSe:SEQuencer:TPLan:LIST?')
		return Conversions.str_to_str_list(response)

	# noinspection PyTypeChecker
	class InfoStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Tp_Name: List[str]: No parameter help available
			- State: List[enums.TestPlanState]: No parameter help available
			- Status: List[enums.Status]: No parameter help available"""
		__meta_args_list = [
			ArgStruct('Tp_Name', DataType.StringList, None, False, True, 1),
			ArgStruct('State', DataType.EnumList, enums.TestPlanState, False, True, 1),
			ArgStruct('Status', DataType.EnumList, enums.Status, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Tp_Name: List[str] = None
			self.State: List[enums.TestPlanState] = None
			self.Status: List[enums.Status] = None

	def get_info(self) -> InfoStruct:
		"""SCPI: SENSe:SEQuencer:TPLan:INFO \n
		Snippet: value: InfoStruct = driver.sense.sequencer.tplan.get_info() \n
		No command help available \n
			:return: structure: for return value, see the help for InfoStruct structure arguments.
		"""
		return self._core.io.query_struct('SENSe:SEQuencer:TPLan:INFO?', self.__class__.InfoStruct())

	def clone(self) -> 'Tplan':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tplan(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Arb:
	"""Arb commands group definition. 13 total commands, 3 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("arb", core, parent)

	@property
	def file(self):
		"""file commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_file'):
			from .Arb_.File import File
			self._file = File(self._core, self._base)
		return self._file

	@property
	def marker(self):
		"""marker commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_marker'):
			from .Arb_.Marker import Marker
			self._marker = Marker(self._core, self._base)
		return self._marker

	@property
	def samples(self):
		"""samples commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_samples'):
			from .Arb_.Samples import Samples
			self._samples = Samples(self._core, self._base)
		return self._samples

	def get_crate(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:CRATe \n
		Snippet: value: float = driver.source.afRf.generator.arb.get_crate() \n
		Queries the clock rate of the loaded ARB file. \n
			:return: clock_rate: Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:ARB:CRATe?')
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def get_crc_protect(self) -> enums.YesNoStatus:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:CRCProtect \n
		Snippet: value: enums.YesNoStatus = driver.source.afRf.generator.arb.get_crc_protect() \n
		Queries whether the loaded ARB file contains a CRC checksum. \n
			:return: crc_protection: NO | YES
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:ARB:CRCProtect?')
		return Conversions.str_to_scalar_enum(response, enums.YesNoStatus)

	def get_foffset(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:FOFFset \n
		Snippet: value: float = driver.source.afRf.generator.arb.get_foffset() \n
		Defines a frequency offset to be imposed at the baseband during ARB generation. \n
			:return: frequency_offset: Range: -10 MHz to 10 MHz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:ARB:FOFFset?')
		return Conversions.str_to_float(response)

	def set_foffset(self, frequency_offset: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:FOFFset \n
		Snippet: driver.source.afRf.generator.arb.set_foffset(frequency_offset = 1.0) \n
		Defines a frequency offset to be imposed at the baseband during ARB generation. \n
			:param frequency_offset: Range: -10 MHz to 10 MHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(frequency_offset)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:ARB:FOFFset {param}')

	def get_loffset(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:LOFFset \n
		Snippet: value: float = driver.source.afRf.generator.arb.get_loffset() \n
		Queries the peak to average ratio (PAR) of the loaded ARB file. The PAR is also called level offset. \n
			:return: level_offset: Unit: dB
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:ARB:LOFFset?')
		return Conversions.str_to_float(response)

	def get_poffset(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:POFFset \n
		Snippet: value: float = driver.source.afRf.generator.arb.get_poffset() \n
		Queries the peak offset of the loaded ARB file. \n
			:return: peak_offset: Unit: dB
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:ARB:POFFset?')
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def get_repetition(self) -> enums.RepeatMode:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:REPetition \n
		Snippet: value: enums.RepeatMode = driver.source.afRf.generator.arb.get_repetition() \n
		Defines how often the ARB file is processed. \n
			:return: repetition: CONTinuous | SINGle CONTinuous Cyclic continuous processing SINGle File is processed once
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:ARB:REPetition?')
		return Conversions.str_to_scalar_enum(response, enums.RepeatMode)

	def set_repetition(self, repetition: enums.RepeatMode) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:REPetition \n
		Snippet: driver.source.afRf.generator.arb.set_repetition(repetition = enums.RepeatMode.CONTinuous) \n
		Defines how often the ARB file is processed. \n
			:param repetition: CONTinuous | SINGle CONTinuous Cyclic continuous processing SINGle File is processed once
		"""
		param = Conversions.enum_scalar_to_str(repetition, enums.RepeatMode)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:ARB:REPetition {param}')

	def clone(self) -> 'Arb':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Arb(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("enable", core, parent)

	def set(self, tone_status: bool, internalGen=repcap.InternalGen.Default, toneNumber=repcap.ToneNumber.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:MTONe:TONE<no>:ENABle \n
		Snippet: driver.source.afRf.generator.internalGenerator.multiTone.tone.enable.set(tone_status = False, internalGen = repcap.InternalGen.Default, toneNumber = repcap.ToneNumber.Default) \n
		Enables or disables a selected tone list entry for multitone generation. \n
			:param tone_status: OFF | ON
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')
			:param toneNumber: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tone')"""
		param = Conversions.bool_to_str(tone_status)
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		toneNumber_cmd_val = self._base.get_repcap_cmd_value(toneNumber, repcap.ToneNumber)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:MTONe:TONE{toneNumber_cmd_val}:ENABle {param}')

	def get(self, internalGen=repcap.InternalGen.Default, toneNumber=repcap.ToneNumber.Default) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:MTONe:TONE<no>:ENABle \n
		Snippet: value: bool = driver.source.afRf.generator.internalGenerator.multiTone.tone.enable.get(internalGen = repcap.InternalGen.Default, toneNumber = repcap.ToneNumber.Default) \n
		Enables or disables a selected tone list entry for multitone generation. \n
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')
			:param toneNumber: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tone')
			:return: tone_status: OFF | ON"""
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		toneNumber_cmd_val = self._base.get_repcap_cmd_value(toneNumber, repcap.ToneNumber)
		response = self._core.io.query_str(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:MTONe:TONE{toneNumber_cmd_val}:ENABle?')
		return Conversions.str_to_bool(response)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Frequency_.Auto import Auto
			self._auto = Auto(self._core, self._base)
		return self._auto

	def set(self, frequency: List[float], internalGen=repcap.InternalGen.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:MTONe:FREQuency \n
		Snippet: driver.source.afRf.generator.internalGenerator.multiTone.frequency.set(frequency = [1.1, 2.2, 3.3], internalGen = repcap.InternalGen.Default) \n
		Configures the frequencies of a multitone signal. \n
			:param frequency: Comma-separated list of up to 20 frequencies, tone 1 to tone 20 You can specify fewer than 20 values to configure only the beginning of the tone list. Range: 20 Hz to 21 kHz, Unit: Hz
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')"""
		param = Conversions.list_to_csv_str(frequency)
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:MTONe:FREQuency {param}')

	def get(self, internalGen=repcap.InternalGen.Default) -> List[float]:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:MTONe:FREQuency \n
		Snippet: value: List[float] = driver.source.afRf.generator.internalGenerator.multiTone.frequency.get(internalGen = repcap.InternalGen.Default) \n
		Configures the frequencies of a multitone signal. \n
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')
			:return: frequency: Comma-separated list of up to 20 frequencies, tone 1 to tone 20 You can specify fewer than 20 values to configure only the beginning of the tone list. Range: 20 Hz to 21 kHz, Unit: Hz"""
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		response = self._core.io.query_bin_or_ascii_float_list(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:MTONe:FREQuency?')
		return response

	def clone(self) -> 'Frequency':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Frequency(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Digital:
	"""Digital commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("digital", core, parent)

	@property
	def rf(self):
		"""rf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rf'):
			from .Digital_.Rf import Rf
			self._rf = Rf(self._core, self._base)
		return self._rf

	def get_file(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIGital:FILE \n
		Snippet: value: str = driver.source.afRf.generator.digital.get_file() \n
		No command help available \n
			:return: arb_file: No help available
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:DIGital:FILE?')
		return trim_str_response(response)

	def set_file(self, arb_file: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIGital:FILE \n
		Snippet: driver.source.afRf.generator.digital.set_file(arb_file = '1') \n
		No command help available \n
			:param arb_file: No help available
		"""
		param = Conversions.value_to_quoted_str(arb_file)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:DIGital:FILE {param}')

	def clone(self) -> 'Digital':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Digital(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("enable", core, parent)

	def set(self, test_af: bool, audioInput=repcap.AudioInput.Default) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:ENABle \n
		Snippet: driver.configure.afRf.measurement.audioInput.enable.set(test_af = False, audioInput = repcap.AudioInput.Default) \n
		Enables or disables an AF IN connector. \n
			:param test_af: OFF | ON Switches the connector off or on
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')"""
		param = Conversions.bool_to_str(test_af)
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:ENABle {param}')

	def get(self, audioInput=repcap.AudioInput.Default) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:ENABle \n
		Snippet: value: bool = driver.configure.afRf.measurement.audioInput.enable.get(audioInput = repcap.AudioInput.Default) \n
		Enables or disables an AF IN connector. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: test_af: OFF | ON Switches the connector off or on"""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		response = self._core.io.query_str(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:ENABle?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IdSignal:
	"""IdSignal commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("idSignal", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:IDSignal:ENABle \n
		Snippet: value: bool = driver.source.avionics.generator.ils.localizer.idSignal.get_enable() \n
		Enables or disables the ID signal. \n
			:return: enable: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:IDSignal:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:IDSignal:ENABle \n
		Snippet: driver.source.avionics.generator.ils.localizer.idSignal.set_enable(enable = False) \n
		Enables or disables the ID signal. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:IDSignal:ENABle {param}')

	def get_mod_depth(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:IDSignal:MDEPth \n
		Snippet: value: float = driver.source.avionics.generator.ils.localizer.idSignal.get_mod_depth() \n
		Configures the modulation depth for the ID signal. The sum of the SDM and of the modulation depth for the ID signal must
		not exceed 100 % (if both signals are enabled) . \n
			:return: mod_depth: Range: 0 % to 100 %, Unit: %
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:IDSignal:MDEPth?')
		return Conversions.str_to_float(response)

	def set_mod_depth(self, mod_depth: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:IDSignal:MDEPth \n
		Snippet: driver.source.avionics.generator.ils.localizer.idSignal.set_mod_depth(mod_depth = 1.0) \n
		Configures the modulation depth for the ID signal. The sum of the SDM and of the modulation depth for the ID signal must
		not exceed 100 % (if both signals are enabled) . \n
			:param mod_depth: Range: 0 % to 100 %, Unit: %
		"""
		param = Conversions.decimal_value_to_str(mod_depth)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:IDSignal:MDEPth {param}')

	def get_frequency(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:IDSignal:FREQuency \n
		Snippet: value: float = driver.source.avionics.generator.ils.localizer.idSignal.get_frequency() \n
		Configures the audio frequency of the ID signal. \n
			:return: freq: Range: 0 Hz to 21 kHz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:IDSignal:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, freq: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:IDSignal:FREQuency \n
		Snippet: driver.source.avionics.generator.ils.localizer.idSignal.set_frequency(freq = 1.0) \n
		Configures the audio frequency of the ID signal. \n
			:param freq: Range: 0 Hz to 21 kHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(freq)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:IDSignal:FREQuency {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ils:
	"""Ils commands group definition. 37 total commands, 3 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ils", core, parent)

	@property
	def localizer(self):
		"""localizer commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_localizer'):
			from .Ils_.Localizer import Localizer
			self._localizer = Localizer(self._core, self._base)
		return self._localizer

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_state'):
			from .Ils_.State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def gslope(self):
		"""gslope commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_gslope'):
			from .Ils_.Gslope import Gslope
			self._gslope = Gslope(self._core, self._base)
		return self._gslope

	def get_fpairment(self) -> bool:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:FPAirment \n
		Snippet: value: bool = driver.source.avionics.generator.ils.get_fpairment() \n
		Enables or disables 'Frequency Pairment', that is the coupling between the glide slope carrier frequency and the
		localizer carrier frequency. \n
			:return: pairment: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:ILS:FPAirment?')
		return Conversions.str_to_bool(response)

	def set_fpairment(self, pairment: bool) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:FPAirment \n
		Snippet: driver.source.avionics.generator.ils.set_fpairment(pairment = False) \n
		Enables or disables 'Frequency Pairment', that is the coupling between the glide slope carrier frequency and the
		localizer carrier frequency. \n
			:param pairment: OFF | ON
		"""
		param = Conversions.bool_to_str(pairment)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:ILS:FPAirment {param}')

	# noinspection PyTypeChecker
	def get_value(self) -> enums.IlsTab:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS \n
		Snippet: value: enums.IlsTab = driver.source.avionics.generator.ils.get_value() \n
		Selects the ILS generator subtab to be displayed at the GUI. \n
			:return: ils_tab: LOCalizer | GSLope
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:ILS?')
		return Conversions.str_to_scalar_enum(response, enums.IlsTab)

	def set_value(self, ils_tab: enums.IlsTab) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS \n
		Snippet: driver.source.avionics.generator.ils.set_value(ils_tab = enums.IlsTab.GSLope) \n
		Selects the ILS generator subtab to be displayed at the GUI. \n
			:param ils_tab: LOCalizer | GSLope
		"""
		param = Conversions.enum_scalar_to_str(ils_tab, enums.IlsTab)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:ILS {param}')

	def clone(self) -> 'Ils':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Ils(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal import Conversions
from .. import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Unit:
	"""Unit commands group definition. 14 total commands, 0 Sub-groups, 14 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("unit", core, parent)

	# noinspection PyTypeChecker
	def get_fscale(self) -> enums.DefaultUnitFullScale:
		"""SCPI: UNIT:FSCale \n
		Snippet: value: enums.DefaultUnitFullScale = driver.unit.get_fscale() \n
		Defines the default unit for full-scale settings and full-scale results. This command affects remote control commands. It
		does not affect the presentation at the GUI. \n
			:return: default_unit_full_scale: No help available
		"""
		response = self._core.io.query_str('UNIT:FSCale?')
		return Conversions.str_to_scalar_enum(response, enums.DefaultUnitFullScale)

	def set_fscale(self, default_unit_full_scale: enums.DefaultUnitFullScale) -> None:
		"""SCPI: UNIT:FSCale \n
		Snippet: driver.unit.set_fscale(default_unit_full_scale = enums.DefaultUnitFullScale.DBFS) \n
		Defines the default unit for full-scale settings and full-scale results. This command affects remote control commands. It
		does not affect the presentation at the GUI. \n
			:param default_unit_full_scale: FS | PCT Means: FS, %
		"""
		param = Conversions.enum_scalar_to_str(default_unit_full_scale, enums.DefaultUnitFullScale)
		self._core.io.write(f'UNIT:FSCale {param}')

	# noinspection PyTypeChecker
	def get_conductance(self) -> enums.DefaultUnitConductance:
		"""SCPI: UNIT:CONDuctance \n
		Snippet: value: enums.DefaultUnitConductance = driver.unit.get_conductance() \n
		No command help available \n
			:return: default_unit_conductance: No help available
		"""
		response = self._core.io.query_str('UNIT:CONDuctance?')
		return Conversions.str_to_scalar_enum(response, enums.DefaultUnitConductance)

	def set_conductance(self, default_unit_conductance: enums.DefaultUnitConductance) -> None:
		"""SCPI: UNIT:CONDuctance \n
		Snippet: driver.unit.set_conductance(default_unit_conductance = enums.DefaultUnitConductance.ASIE) \n
		No command help available \n
			:param default_unit_conductance: No help available
		"""
		param = Conversions.enum_scalar_to_str(default_unit_conductance, enums.DefaultUnitConductance)
		self._core.io.write(f'UNIT:CONDuctance {param}')

	# noinspection PyTypeChecker
	def get_charge(self) -> enums.DefaultUnitCharge:
		"""SCPI: UNIT:CHARge \n
		Snippet: value: enums.DefaultUnitCharge = driver.unit.get_charge() \n
		No command help available \n
			:return: default_unit_charge: No help available
		"""
		response = self._core.io.query_str('UNIT:CHARge?')
		return Conversions.str_to_scalar_enum(response, enums.DefaultUnitCharge)

	def set_charge(self, default_unit_charge: enums.DefaultUnitCharge) -> None:
		"""SCPI: UNIT:CHARge \n
		Snippet: driver.unit.set_charge(default_unit_charge = enums.DefaultUnitCharge.AC) \n
		No command help available \n
			:param default_unit_charge: No help available
		"""
		param = Conversions.enum_scalar_to_str(default_unit_charge, enums.DefaultUnitCharge)
		self._core.io.write(f'UNIT:CHARge {param}')

	# noinspection PyTypeChecker
	def get_capacity(self) -> enums.DefaultUnitCapacity:
		"""SCPI: UNIT:CAPacity \n
		Snippet: value: enums.DefaultUnitCapacity = driver.unit.get_capacity() \n
		No command help available \n
			:return: default_unit_capacity: No help available
		"""
		response = self._core.io.query_str('UNIT:CAPacity?')
		return Conversions.str_to_scalar_enum(response, enums.DefaultUnitCapacity)

	def set_capacity(self, default_unit_capacity: enums.DefaultUnitCapacity) -> None:
		"""SCPI: UNIT:CAPacity \n
		Snippet: driver.unit.set_capacity(default_unit_capacity = enums.DefaultUnitCapacity.AF) \n
		No command help available \n
			:param default_unit_capacity: No help available
		"""
		param = Conversions.enum_scalar_to_str(default_unit_capacity, enums.DefaultUnitCapacity)
		self._core.io.write(f'UNIT:CAPacity {param}')

	# noinspection PyTypeChecker
	def get_energy(self) -> enums.DefaultUnitEnergy:
		"""SCPI: UNIT:ENERgy \n
		Snippet: value: enums.DefaultUnitEnergy = driver.unit.get_energy() \n
		No command help available \n
			:return: default_unit_energy: No help available
		"""
		response = self._core.io.query_str('UNIT:ENERgy?')
		return Conversions.str_to_scalar_enum(response, enums.DefaultUnitEnergy)

	def set_energy(self, default_unit_energy: enums.DefaultUnitEnergy) -> None:
		"""SCPI: UNIT:ENERgy \n
		Snippet: driver.unit.set_energy(default_unit_energy = enums.DefaultUnitEnergy.AJ) \n
		No command help available \n
			:param default_unit_energy: No help available
		"""
		param = Conversions.enum_scalar_to_str(default_unit_energy, enums.DefaultUnitEnergy)
		self._core.io.write(f'UNIT:ENERgy {param}')

	# noinspection PyTypeChecker
	def get_frequency(self) -> enums.DefaultUnitFrequency:
		"""SCPI: UNIT:FREQuency \n
		Snippet: value: enums.DefaultUnitFrequency = driver.unit.get_frequency() \n
		Defines the default unit for frequency settings and frequency results. This command affects remote control commands.
		It does not affect the frequency value presentation at the GUI. \n
			:return: default_unit_frequency: No help available
		"""
		response = self._core.io.query_str('UNIT:FREQuency?')
		return Conversions.str_to_scalar_enum(response, enums.DefaultUnitFrequency)

	def set_frequency(self, default_unit_frequency: enums.DefaultUnitFrequency) -> None:
		"""SCPI: UNIT:FREQuency \n
		Snippet: driver.unit.set_frequency(default_unit_frequency = enums.DefaultUnitFrequency.AHZ) \n
		Defines the default unit for frequency settings and frequency results. This command affects remote control commands.
		It does not affect the frequency value presentation at the GUI. \n
			:param default_unit_frequency: HZ | KHZ | MHZ | GHZ Means: Hz, kHz, MHz, GHz
		"""
		param = Conversions.enum_scalar_to_str(default_unit_frequency, enums.DefaultUnitFrequency)
		self._core.io.write(f'UNIT:FREQuency {param}')

	# noinspection PyTypeChecker
	def get_resistor(self) -> enums.DefaultUnitResistor:
		"""SCPI: UNIT:RESistor \n
		Snippet: value: enums.DefaultUnitResistor = driver.unit.get_resistor() \n
		No command help available \n
			:return: default_unit_resistor: No help available
		"""
		response = self._core.io.query_str('UNIT:RESistor?')
		return Conversions.str_to_scalar_enum(response, enums.DefaultUnitResistor)

	def set_resistor(self, default_unit_resistor: enums.DefaultUnitResistor) -> None:
		"""SCPI: UNIT:RESistor \n
		Snippet: driver.unit.set_resistor(default_unit_resistor = enums.DefaultUnitResistor.AOHM) \n
		No command help available \n
			:param default_unit_resistor: No help available
		"""
		param = Conversions.enum_scalar_to_str(default_unit_resistor, enums.DefaultUnitResistor)
		self._core.io.write(f'UNIT:RESistor {param}')

	# noinspection PyTypeChecker
	def get_voltage(self) -> enums.DefaultUnitVoltage:
		"""SCPI: UNIT:VOLTage \n
		Snippet: value: enums.DefaultUnitVoltage = driver.unit.get_voltage() \n
		Defines the default unit for voltage settings and voltage results. This command affects remote control commands. It does
		not affect the voltage value presentation at the GUI. \n
			:return: default_unit_voltage: No help available
		"""
		response = self._core.io.query_str('UNIT:VOLTage?')
		return Conversions.str_to_scalar_enum(response, enums.DefaultUnitVoltage)

	def set_voltage(self, default_unit_voltage: enums.DefaultUnitVoltage) -> None:
		"""SCPI: UNIT:VOLTage \n
		Snippet: driver.unit.set_voltage(default_unit_voltage = enums.DefaultUnitVoltage.AV) \n
		Defines the default unit for voltage settings and voltage results. This command affects remote control commands. It does
		not affect the voltage value presentation at the GUI. \n
			:param default_unit_voltage: V | MV | UV | DBV | DBMV | DBUV Means: V, mV, µV, dBV, dBmV, dBµV
		"""
		param = Conversions.enum_scalar_to_str(default_unit_voltage, enums.DefaultUnitVoltage)
		self._core.io.write(f'UNIT:VOLTage {param}')

	# noinspection PyTypeChecker
	def get_angle(self) -> enums.DefaultUnitAngle:
		"""SCPI: UNIT:ANGLe \n
		Snippet: value: enums.DefaultUnitAngle = driver.unit.get_angle() \n
		Defines the default unit for angle settings and angle results. This command affects remote control commands. It does not
		affect the angle value presentation at the GUI. \n
			:return: default_unit_angle: No help available
		"""
		response = self._core.io.query_str('UNIT:ANGLe?')
		return Conversions.str_to_scalar_enum(response, enums.DefaultUnitAngle)

	def set_angle(self, default_unit_angle: enums.DefaultUnitAngle) -> None:
		"""SCPI: UNIT:ANGLe \n
		Snippet: driver.unit.set_angle(default_unit_angle = enums.DefaultUnitAngle.DEG) \n
		Defines the default unit for angle settings and angle results. This command affects remote control commands. It does not
		affect the angle value presentation at the GUI. \n
			:param default_unit_angle: DEG | RAD Means: degrees, radians
		"""
		param = Conversions.enum_scalar_to_str(default_unit_angle, enums.DefaultUnitAngle)
		self._core.io.write(f'UNIT:ANGLe {param}')

	# noinspection PyTypeChecker
	def get_length(self) -> enums.DefaultUnitLenght:
		"""SCPI: UNIT:LENGth \n
		Snippet: value: enums.DefaultUnitLenght = driver.unit.get_length() \n
		No command help available \n
			:return: default_unit_lenght: No help available
		"""
		response = self._core.io.query_str('UNIT:LENGth?')
		return Conversions.str_to_scalar_enum(response, enums.DefaultUnitLenght)

	def set_length(self, default_unit_lenght: enums.DefaultUnitLenght) -> None:
		"""SCPI: UNIT:LENGth \n
		Snippet: driver.unit.set_length(default_unit_lenght = enums.DefaultUnitLenght.AM) \n
		No command help available \n
			:param default_unit_lenght: No help available
		"""
		param = Conversions.enum_scalar_to_str(default_unit_lenght, enums.DefaultUnitLenght)
		self._core.io.write(f'UNIT:LENGth {param}')

	# noinspection PyTypeChecker
	def get_current(self) -> enums.DefaultUnitCurrent:
		"""SCPI: UNIT:CURRent \n
		Snippet: value: enums.DefaultUnitCurrent = driver.unit.get_current() \n
		No command help available \n
			:return: default_unit_current: No help available
		"""
		response = self._core.io.query_str('UNIT:CURRent?')
		return Conversions.str_to_scalar_enum(response, enums.DefaultUnitCurrent)

	def set_current(self, default_unit_current: enums.DefaultUnitCurrent) -> None:
		"""SCPI: UNIT:CURRent \n
		Snippet: driver.unit.set_current(default_unit_current = enums.DefaultUnitCurrent.A) \n
		No command help available \n
			:param default_unit_current: No help available
		"""
		param = Conversions.enum_scalar_to_str(default_unit_current, enums.DefaultUnitCurrent)
		self._core.io.write(f'UNIT:CURRent {param}')

	# noinspection PyTypeChecker
	def get_power(self) -> enums.DefaultUnitPower:
		"""SCPI: UNIT:POWer \n
		Snippet: value: enums.DefaultUnitPower = driver.unit.get_power() \n
		Defines the default unit for power settings and power results. This command affects remote control commands. It does not
		affect the power value presentation at the GUI. \n
			:return: default_unit_power: No help available
		"""
		response = self._core.io.query_str('UNIT:POWer?')
		return Conversions.str_to_scalar_enum(response, enums.DefaultUnitPower)

	def set_power(self, default_unit_power: enums.DefaultUnitPower) -> None:
		"""SCPI: UNIT:POWer \n
		Snippet: driver.unit.set_power(default_unit_power = enums.DefaultUnitPower.AW) \n
		Defines the default unit for power settings and power results. This command affects remote control commands. It does not
		affect the power value presentation at the GUI. \n
			:param default_unit_power: W | MIW | DBMW | DBW Means: W, mW, dBm, dBW
		"""
		param = Conversions.enum_scalar_to_str(default_unit_power, enums.DefaultUnitPower)
		self._core.io.write(f'UNIT:POWer {param}')

	# noinspection PyTypeChecker
	def get_temperature(self) -> enums.DefaultUnitTemperature:
		"""SCPI: UNIT:TEMPerature \n
		Snippet: value: enums.DefaultUnitTemperature = driver.unit.get_temperature() \n
		No command help available \n
			:return: default_unit_temperature: No help available
		"""
		response = self._core.io.query_str('UNIT:TEMPerature?')
		return Conversions.str_to_scalar_enum(response, enums.DefaultUnitTemperature)

	def set_temperature(self, default_unit_temperature: enums.DefaultUnitTemperature) -> None:
		"""SCPI: UNIT:TEMPerature \n
		Snippet: driver.unit.set_temperature(default_unit_temperature = enums.DefaultUnitTemperature.C) \n
		No command help available \n
			:param default_unit_temperature: No help available
		"""
		param = Conversions.enum_scalar_to_str(default_unit_temperature, enums.DefaultUnitTemperature)
		self._core.io.write(f'UNIT:TEMPerature {param}')

	# noinspection PyTypeChecker
	def get_time(self) -> enums.DefaultUnitTime:
		"""SCPI: UNIT:TIME \n
		Snippet: value: enums.DefaultUnitTime = driver.unit.get_time() \n
		Defines the default unit for time settings and time results. This command affects remote control commands. It does not
		affect the time value presentation at the GUI. \n
			:return: default_unit_time: No help available
		"""
		response = self._core.io.query_str('UNIT:TIME?')
		return Conversions.str_to_scalar_enum(response, enums.DefaultUnitTime)

	def set_time(self, default_unit_time: enums.DefaultUnitTime) -> None:
		"""SCPI: UNIT:TIME \n
		Snippet: driver.unit.set_time(default_unit_time = enums.DefaultUnitTime.AS) \n
		Defines the default unit for time settings and time results. This command affects remote control commands. It does not
		affect the time value presentation at the GUI. \n
			:param default_unit_time: M | S | MS | US | NS Means: minutes, seconds, ms, µs, ns
		"""
		param = Conversions.enum_scalar_to_str(default_unit_time, enums.DefaultUnitTime)
		self._core.io.write(f'UNIT:TIME {param}')



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Types import DataType
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Exceeded:
	"""Exceeded commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("exceeded", core, parent)

	# noinspection PyTypeChecker
	class ListPyStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Meas_Point: List[str]: No parameter help available
			- Current_Temp: List[float]: No parameter help available
			- Max_Temp: List[float]: No parameter help available"""
		__meta_args_list = [
			ArgStruct('Meas_Point', DataType.StringList, None, False, True, 1),
			ArgStruct('Current_Temp', DataType.FloatList, None, False, True, 1),
			ArgStruct('Max_Temp', DataType.FloatList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Meas_Point: List[str] = None
			self.Current_Temp: List[float] = None
			self.Max_Temp: List[float] = None

	def get_list_py(self) -> ListPyStruct:
		"""SCPI: SENSe:BASE:TEMPerature:EXCeeded:LIST \n
		Snippet: value: ListPyStruct = driver.sense.base.temperature.exceeded.get_list_py() \n
		No command help available \n
			:return: structure: for return value, see the help for ListPyStruct structure arguments.
		"""
		return self._core.io.query_struct('SENSe:BASE:TEMPerature:EXCeeded:LIST?', self.__class__.ListPyStruct())

	def get_value(self) -> bool:
		"""SCPI: SENSe:BASE:TEMPerature:EXCeeded \n
		Snippet: value: bool = driver.sense.base.temperature.exceeded.get_value() \n
		No command help available \n
			:return: exceed: No help available
		"""
		response = self._core.io.query_str('SENSe:BASE:TEMPerature:EXCeeded?')
		return Conversions.str_to_bool(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.RepeatedCapability import RepeatedCapability
from .... import enums
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Relay:
	"""Relay commands group definition. 1 total commands, 0 Sub-groups, 1 group commands
	Repeated Capability: Relay, default value after init: Relay.Ix1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("relay", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_relay_get', 'repcap_relay_set', repcap.Relay.Ix1)

	def repcap_relay_set(self, enum_value: repcap.Relay) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Relay.Default
		Default value after init: Relay.Ix1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_relay_get(self) -> repcap.Relay:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	def set(self, activity: enums.Activity, relay=repcap.Relay.Default) -> None:
		"""SCPI: CONFigure:BASE:RELay<Index> \n
		Snippet: driver.configure.base.relay.set(activity = enums.Activity.ACTive, relay = repcap.Relay.Default) \n
		Activates or deactivates relay 1 or 2 of the CONTROL connector. \n
			:param activity: INACtive | ACTive
			:param relay: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Relay')"""
		param = Conversions.enum_scalar_to_str(activity, enums.Activity)
		relay_cmd_val = self._base.get_repcap_cmd_value(relay, repcap.Relay)
		self._core.io.write(f'CONFigure:BASE:RELay{relay_cmd_val} {param}')

	# noinspection PyTypeChecker
	def get(self, relay=repcap.Relay.Default) -> enums.Activity:
		"""SCPI: CONFigure:BASE:RELay<Index> \n
		Snippet: value: enums.Activity = driver.configure.base.relay.get(relay = repcap.Relay.Default) \n
		Activates or deactivates relay 1 or 2 of the CONTROL connector. \n
			:param relay: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Relay')
			:return: activity: INACtive | ACTive"""
		relay_cmd_val = self._base.get_repcap_cmd_value(relay, repcap.Relay)
		response = self._core.io.query_str(f'CONFigure:BASE:RELay{relay_cmd_val}?')
		return Conversions.str_to_scalar_enum(response, enums.Activity)

	def clone(self) -> 'Relay':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Relay(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Direction:
	"""Direction commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("direction", core, parent)

	def set(self, direction: enums.DirectionIo, tTL=repcap.TTL.Default) -> None:
		"""SCPI: CONFigure:BASE:TTL<Index>:DIRection \n
		Snippet: driver.configure.base.ttl.direction.set(direction = enums.DirectionIo.IN, tTL = repcap.TTL.Default) \n
		Configures the direction of a TTL register of the CONTROL connector. The direction of register 1 is fixed and can only be
		queried. The direction of register 2 can be configured. \n
			:param direction: IN | OUT
			:param tTL: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Ttl')"""
		param = Conversions.enum_scalar_to_str(direction, enums.DirectionIo)
		tTL_cmd_val = self._base.get_repcap_cmd_value(tTL, repcap.TTL)
		self._core.io.write(f'CONFigure:BASE:TTL{tTL_cmd_val}:DIRection {param}')

	# noinspection PyTypeChecker
	def get(self, tTL=repcap.TTL.Default) -> enums.DirectionIo:
		"""SCPI: CONFigure:BASE:TTL<Index>:DIRection \n
		Snippet: value: enums.DirectionIo = driver.configure.base.ttl.direction.get(tTL = repcap.TTL.Default) \n
		Configures the direction of a TTL register of the CONTROL connector. The direction of register 1 is fixed and can only be
		queried. The direction of register 2 can be configured. \n
			:param tTL: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Ttl')
			:return: direction: IN | OUT"""
		tTL_cmd_val = self._base.get_repcap_cmd_value(tTL, repcap.TTL)
		response = self._core.io.query_str(f'CONFigure:BASE:TTL{tTL_cmd_val}:DIRection?')
		return Conversions.str_to_scalar_enum(response, enums.DirectionIo)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Estatus:
	"""Estatus commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("estatus", core, parent)

	# noinspection PyTypeChecker
	def get(self, tp_name: str) -> enums.Status:
		"""SCPI: SENSe:SEQuencer:TPLan:ESTatus \n
		Snippet: value: enums.Status = driver.sense.sequencer.tplan.estatus.get(tp_name = '1') \n
		No command help available \n
			:param tp_name: No help available
			:return: status: No help available"""
		param = Conversions.value_to_quoted_str(tp_name)
		response = self._core.io.query_str(f'SENSe:SEQuencer:TPLan:ESTatus? {param}')
		return Conversions.str_to_scalar_enum(response, enums.Status)



from typing import List

from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)

	def reset(self) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SCAL:FREQuency:RESet \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.scal.frequency.reset() \n
		No command help available \n
		"""
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SCAL:FREQuency:RESet')

	def reset_with_opc(self) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SCAL:FREQuency:RESet \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.scal.frequency.reset_with_opc() \n
		No command help available \n
		Same as reset, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SCAL:FREQuency:RESet')

	def get_value(self) -> List[float]:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SCAL:FREQuency \n
		Snippet: value: List[float] = driver.configure.afRf.measurement.multiEval.tones.scal.frequency.get_value() \n
		Configures the user-defined tone table for SELCAL. To enable the table, see method RsCma.Configure.AfRf.Measurement.
		MultiEval.Tones.Scal.UserDefined.enable. \n
			:return: frequency: Comma-separated list of up to 16 frequencies You can specify fewer than 16 values to configure only the beginning of the tone table. Range: see table , Unit: Hz
		"""
		response = self._core.io.query_bin_or_ascii_float_list('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SCAL:FREQuency?')
		return response

	def set_value(self, frequency: List[float]) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SCAL:FREQuency \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.scal.frequency.set_value(frequency = [1.1, 2.2, 3.3]) \n
		Configures the user-defined tone table for SELCAL. To enable the table, see method RsCma.Configure.AfRf.Measurement.
		MultiEval.Tones.Scal.UserDefined.enable. \n
			:param frequency: Comma-separated list of up to 16 frequencies You can specify fewer than 16 values to configure only the beginning of the tone table. Range: see table , Unit: Hz
		"""
		param = Conversions.list_to_csv_str(frequency)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SCAL:FREQuency {param}')



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Status:
	"""Status commands group definition. 37 total commands, 7 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("status", core, parent)

	@property
	def queue(self):
		"""queue commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_queue'):
			from .Status_.Queue import Queue
			self._queue = Queue(self._core, self._base)
		return self._queue

	@property
	def operation(self):
		"""operation commands group. 1 Sub-classes, 5 commands."""
		if not hasattr(self, '_operation'):
			from .Status_.Operation import Operation
			self._operation = Operation(self._core, self._base)
		return self._operation

	@property
	def questionable(self):
		"""questionable commands group. 1 Sub-classes, 5 commands."""
		if not hasattr(self, '_questionable'):
			from .Status_.Questionable import Questionable
			self._questionable = Questionable(self._core, self._base)
		return self._questionable

	@property
	def condition(self):
		"""condition commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_condition'):
			from .Status_.Condition import Condition
			self._condition = Condition(self._core, self._base)
		return self._condition

	@property
	def event(self):
		"""event commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_event'):
			from .Status_.Event import Event
			self._event = Event(self._core, self._base)
		return self._event

	@property
	def measurement(self):
		"""measurement commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_measurement'):
			from .Status_.Measurement import Measurement
			self._measurement = Measurement(self._core, self._base)
		return self._measurement

	@property
	def generator(self):
		"""generator commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_generator'):
			from .Status_.Generator import Generator
			self._generator = Generator(self._core, self._base)
		return self._generator

	def preset(self) -> None:
		"""SCPI: STATus:PRESet \n
		Snippet: driver.status.preset() \n
		No command help available \n
		"""
		self._core.io.write(f'STATus:PRESet')

	def preset_with_opc(self) -> None:
		"""SCPI: STATus:PRESet \n
		Snippet: driver.status.preset_with_opc() \n
		No command help available \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'STATus:PRESet')

	def clone(self) -> 'Status':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Status(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Limit:
	"""Limit commands group definition. 5 total commands, 0 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("limit", core, parent)

	# noinspection PyTypeChecker
	class EnableStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Power: bool: OFF | ON
			- Return_Loss: bool: OFF | ON
			- Reflection: bool: OFF | ON
			- Swr: bool: OFF | ON"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Power'),
			ArgStruct.scalar_bool('Return_Loss'),
			ArgStruct.scalar_bool('Reflection'),
			ArgStruct.scalar_bool('Swr')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Power: bool = None
			self.Return_Loss: bool = None
			self.Reflection: bool = None
			self.Swr: bool = None

	def get_enable(self) -> EnableStruct:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:ENABle \n
		Snippet: value: EnableStruct = driver.configure.gprfMeasurement.nrt.reverse.limit.get_enable() \n
		Enables/disables the limit check for the reverse direction results. \n
			:return: structure: for return value, see the help for EnableStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:ENABle?', self.__class__.EnableStruct())

	def set_enable(self, value: EnableStruct) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:ENABle \n
		Snippet: driver.configure.gprfMeasurement.nrt.reverse.limit.set_enable(value = EnableStruct()) \n
		Enables/disables the limit check for the reverse direction results. \n
			:param value: see the help for EnableStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:ENABle', value)

	# noinspection PyTypeChecker
	class PowerStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Lower: float: Range: Depends on sensor model , Unit: dBm
			- Upper: float: Range: Depends on sensor model , Unit: dBm"""
		__meta_args_list = [
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Lower: float = None
			self.Upper: float = None

	def get_power(self) -> PowerStruct:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:POWer \n
		Snippet: value: PowerStruct = driver.configure.gprfMeasurement.nrt.reverse.limit.get_power() \n
		Configures limits for the reverse power results. \n
			:return: structure: for return value, see the help for PowerStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:POWer?', self.__class__.PowerStruct())

	def set_power(self, value: PowerStruct) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:POWer \n
		Snippet: driver.configure.gprfMeasurement.nrt.reverse.limit.set_power(value = PowerStruct()) \n
		Configures limits for the reverse power results. \n
			:param value: see the help for PowerStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:POWer', value)

	# noinspection PyTypeChecker
	class RlossStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Lower: float: Range: 0 dB to 50 dB, Unit: dB
			- Upper: float: Range: 0 dB to 50 dB, Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Lower: float = None
			self.Upper: float = None

	def get_rloss(self) -> RlossStruct:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:RLOSs \n
		Snippet: value: RlossStruct = driver.configure.gprfMeasurement.nrt.reverse.limit.get_rloss() \n
		Configures limits for the return loss results. \n
			:return: structure: for return value, see the help for RlossStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:RLOSs?', self.__class__.RlossStruct())

	def set_rloss(self, value: RlossStruct) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:RLOSs \n
		Snippet: driver.configure.gprfMeasurement.nrt.reverse.limit.set_rloss(value = RlossStruct()) \n
		Configures limits for the return loss results. \n
			:param value: see the help for RlossStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:RLOSs', value)

	# noinspection PyTypeChecker
	class ReflectionStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Lower: float: Range: 0 % to 100 %, Unit: %
			- Upper: float: Range: 0 % to 100 %, Unit: %"""
		__meta_args_list = [
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Lower: float = None
			self.Upper: float = None

	def get_reflection(self) -> ReflectionStruct:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:REFLection \n
		Snippet: value: ReflectionStruct = driver.configure.gprfMeasurement.nrt.reverse.limit.get_reflection() \n
		Configures limits for the reflection results. \n
			:return: structure: for return value, see the help for ReflectionStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:REFLection?', self.__class__.ReflectionStruct())

	def set_reflection(self, value: ReflectionStruct) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:REFLection \n
		Snippet: driver.configure.gprfMeasurement.nrt.reverse.limit.set_reflection(value = ReflectionStruct()) \n
		Configures limits for the reflection results. \n
			:param value: see the help for ReflectionStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:REFLection', value)

	# noinspection PyTypeChecker
	class SwrStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Lower: float: Range: 1 to 50
			- Upper: float: Range: 1 to 50"""
		__meta_args_list = [
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Lower: float = None
			self.Upper: float = None

	def get_swr(self) -> SwrStruct:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:SWR \n
		Snippet: value: SwrStruct = driver.configure.gprfMeasurement.nrt.reverse.limit.get_swr() \n
		Configures limits for the SWR results. \n
			:return: structure: for return value, see the help for SwrStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:SWR?', self.__class__.SwrStruct())

	def set_swr(self, value: SwrStruct) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:SWR \n
		Snippet: driver.configure.gprfMeasurement.nrt.reverse.limit.set_swr(value = SwrStruct()) \n
		Configures limits for the SWR results. \n
			:param value: see the help for SwrStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:LIMit:SWR', value)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 6 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)

	@property
	def delta(self):
		"""delta commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_delta'):
			from .Frequency_.Delta import Delta
			self._delta = Delta(self._core, self._base)
		return self._delta

	def get_atg_frequency(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FREQuency:ATGFrequency \n
		Snippet: value: bool = driver.configure.afRf.measurement.voip.frequency.get_atg_frequency() \n
		Selects whether the carrier center frequency resulting from the FID is copied from the analyzer to the AFRF generator or
		not. \n
			:return: apply_to_gen_rf: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:FREQuency:ATGFrequency?')
		return Conversions.str_to_bool(response)

	def set_atg_frequency(self, apply_to_gen_rf: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FREQuency:ATGFrequency \n
		Snippet: driver.configure.afRf.measurement.voip.frequency.set_atg_frequency(apply_to_gen_rf = False) \n
		Selects whether the carrier center frequency resulting from the FID is copied from the analyzer to the AFRF generator or
		not. \n
			:param apply_to_gen_rf: OFF | ON
		"""
		param = Conversions.bool_to_str(apply_to_gen_rf)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:FREQuency:ATGFrequency {param}')

	# noinspection PyTypeChecker
	class ValueStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Frequency: float: RF carrier center frequency Unit: Hz
			- Channel_Spacing: float: Channel spacing Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_float('Frequency'),
			ArgStruct.scalar_float('Channel_Spacing')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Frequency: float = None
			self.Channel_Spacing: float = None

	def get_value(self) -> ValueStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FREQuency \n
		Snippet: value: ValueStruct = driver.configure.afRf.measurement.voip.frequency.get_value() \n
		Queries the RF carrier center frequency and the channel spacing resulting from the configured frequency ID. \n
			:return: structure: for return value, see the help for ValueStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:VOIP:FREQuency?', self.__class__.ValueStruct())

	def clone(self) -> 'Frequency':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Frequency(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Reliability:
	"""Reliability commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("reliability", core, parent)

	def fetch(self) -> int:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:IQRecorder:RELiability \n
		Snippet: value: int = driver.gprfMeasurement.iqRecorder.reliability.fetch() \n
		Queries the reliability indicator for the I/Q recorder measurement, see 'Reliability indicator values'. \n
			:return: reliability_flag: Two equal values, separated by a comma (for example 0,0 for 'OK')"""
		response = self._core.io.query_str(f'FETCh:GPRF:MEASurement<Instance>:IQRecorder:RELiability?')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MultiEval:
	"""MultiEval commands group definition. 112 total commands, 14 Sub-groups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("multiEval", core, parent)

	@property
	def result(self):
		"""result commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_result'):
			from .MultiEval_.Result import Result
			self._result = Result(self._core, self._base)
		return self._result

	@property
	def afFft(self):
		"""afFft commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_afFft'):
			from .MultiEval_.AfFft import AfFft
			self._afFft = AfFft(self._core, self._base)
		return self._afFft

	@property
	def af(self):
		"""af commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_af'):
			from .MultiEval_.Af import Af
			self._af = Af(self._core, self._base)
		return self._af

	@property
	def rf(self):
		"""rf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rf'):
			from .MultiEval_.Rf import Rf
			self._rf = Rf(self._core, self._base)
		return self._rf

	@property
	def multiTone(self):
		"""multiTone commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_multiTone'):
			from .MultiEval_.MultiTone import MultiTone
			self._multiTone = MultiTone(self._core, self._base)
		return self._multiTone

	@property
	def fft(self):
		"""fft commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_fft'):
			from .MultiEval_.Fft import Fft
			self._fft = Fft(self._core, self._base)
		return self._fft

	@property
	def tones(self):
		"""tones commands group. 11 Sub-classes, 0 commands."""
		if not hasattr(self, '_tones'):
			from .MultiEval_.Tones import Tones
			self._tones = Tones(self._core, self._base)
		return self._tones

	@property
	def demodulation(self):
		"""demodulation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_demodulation'):
			from .MultiEval_.Demodulation import Demodulation
			self._demodulation = Demodulation(self._core, self._base)
		return self._demodulation

	@property
	def audioInput(self):
		"""audioInput commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_audioInput'):
			from .MultiEval_.AudioInput import AudioInput
			self._audioInput = AudioInput(self._core, self._base)
		return self._audioInput

	@property
	def spdifLeft(self):
		"""spdifLeft commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_spdifLeft'):
			from .MultiEval_.SpdifLeft import SpdifLeft
			self._spdifLeft = SpdifLeft(self._core, self._base)
		return self._spdifLeft

	@property
	def spdifRight(self):
		"""spdifRight commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_spdifRight'):
			from .MultiEval_.SpdifRight import SpdifRight
			self._spdifRight = SpdifRight(self._core, self._base)
		return self._spdifRight

	@property
	def limit(self):
		"""limit commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_limit'):
			from .MultiEval_.Limit import Limit
			self._limit = Limit(self._core, self._base)
		return self._limit

	@property
	def oscilloscope(self):
		"""oscilloscope commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_oscilloscope'):
			from .MultiEval_.Oscilloscope import Oscilloscope
			self._oscilloscope = Oscilloscope(self._core, self._base)
		return self._oscilloscope

	@property
	def filterPy(self):
		"""filterPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_filterPy'):
			from .MultiEval_.FilterPy import FilterPy
			self._filterPy = FilterPy(self._core, self._base)
		return self._filterPy

	def get_crepetition(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:CREPetition \n
		Snippet: value: bool = driver.configure.afRf.measurement.multiEval.get_crepetition() \n
		Enables or disables the automatic configuration of the repetition mode. With enabled automatic configuration, the
		repetition mode of all measurements is set to 'Continuous' each time the instrument switches from remote operation to
		manual operation. \n
			:return: continuous_repetition: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:CREPetition?')
		return Conversions.str_to_bool(response)

	def set_crepetition(self, continuous_repetition: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:CREPetition \n
		Snippet: driver.configure.afRf.measurement.multiEval.set_crepetition(continuous_repetition = False) \n
		Enables or disables the automatic configuration of the repetition mode. With enabled automatic configuration, the
		repetition mode of all measurements is set to 'Continuous' each time the instrument switches from remote operation to
		manual operation. \n
			:param continuous_repetition: OFF | ON
		"""
		param = Conversions.bool_to_str(continuous_repetition)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:CREPetition {param}')

	# noinspection PyTypeChecker
	def get_repetition(self) -> enums.Repeat:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:REPetition \n
		Snippet: value: enums.Repeat = driver.configure.afRf.measurement.multiEval.get_repetition() \n
		Selects whether the measurement is repeated continuously or not. \n
			:return: repetition: SINGleshot | CONTinuous SINGleshot Single-shot measurement, stopped after one measurement cycle CONTinuous Continuous measurement, running until explicitly terminated
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:REPetition?')
		return Conversions.str_to_scalar_enum(response, enums.Repeat)

	def set_repetition(self, repetition: enums.Repeat) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:REPetition \n
		Snippet: driver.configure.afRf.measurement.multiEval.set_repetition(repetition = enums.Repeat.CONTinuous) \n
		Selects whether the measurement is repeated continuously or not. \n
			:param repetition: SINGleshot | CONTinuous SINGleshot Single-shot measurement, stopped after one measurement cycle CONTinuous Continuous measurement, running until explicitly terminated
		"""
		param = Conversions.enum_scalar_to_str(repetition, enums.Repeat)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:REPetition {param}')

	# noinspection PyTypeChecker
	def get_scondition(self) -> enums.StopCondition:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:SCONdition \n
		Snippet: value: enums.StopCondition = driver.configure.afRf.measurement.multiEval.get_scondition() \n
		Selects whether the measurement is stopped after a failed limit check or continued. \n
			:return: stop_condition: NONE | SLFail NONE Continue measurement irrespective of the limit check SLFail Stop measurement on limit failure
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:SCONdition?')
		return Conversions.str_to_scalar_enum(response, enums.StopCondition)

	def set_scondition(self, stop_condition: enums.StopCondition) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:SCONdition \n
		Snippet: driver.configure.afRf.measurement.multiEval.set_scondition(stop_condition = enums.StopCondition.NONE) \n
		Selects whether the measurement is stopped after a failed limit check or continued. \n
			:param stop_condition: NONE | SLFail NONE Continue measurement irrespective of the limit check SLFail Stop measurement on limit failure
		"""
		param = Conversions.enum_scalar_to_str(stop_condition, enums.StopCondition)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:SCONdition {param}')

	def get_mo_exception(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:MOEXception \n
		Snippet: value: bool = driver.configure.afRf.measurement.multiEval.get_mo_exception() \n
		Specifies whether measurement results that the R&S CMA180 identifies as faulty or inaccurate are rejected. \n
			:return: meas_on_exception: OFF | ON OFF Faulty results are rejected ON Results are never rejected
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:MOEXception?')
		return Conversions.str_to_bool(response)

	def set_mo_exception(self, meas_on_exception: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:MOEXception \n
		Snippet: driver.configure.afRf.measurement.multiEval.set_mo_exception(meas_on_exception = False) \n
		Specifies whether measurement results that the R&S CMA180 identifies as faulty or inaccurate are rejected. \n
			:param meas_on_exception: OFF | ON OFF Faulty results are rejected ON Results are never rejected
		"""
		param = Conversions.bool_to_str(meas_on_exception)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:MOEXception {param}')

	def get_rcoupling(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:RCOupling \n
		Snippet: value: bool = driver.configure.afRf.measurement.multiEval.get_rcoupling() \n
		Couples the repetition mode (single shot or continuous) of all measurements. \n
			:return: repetition_coupling: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:RCOupling?')
		return Conversions.str_to_bool(response)

	def set_rcoupling(self, repetition_coupling: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:RCOupling \n
		Snippet: driver.configure.afRf.measurement.multiEval.set_rcoupling(repetition_coupling = False) \n
		Couples the repetition mode (single shot or continuous) of all measurements. \n
			:param repetition_coupling: OFF | ON
		"""
		param = Conversions.bool_to_str(repetition_coupling)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:RCOupling {param}')

	def get_timeout(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TOUT \n
		Snippet: value: float = driver.configure.afRf.measurement.multiEval.get_timeout() \n
		Defines a timeout for the measurement. The timer is started when the measurement is initiated via a READ or INIT command.
		It is not started if the measurement is initiated via the graphical user interface. The timer is reset after the first
		measurement cycle. If the first measurement cycle has not been completed when the timer expires, the measurement is
		stopped and the reliability indicator is set to 1. Still running READ, FETCh or CALCulate commands are completed,
		returning the available results. At least for some results, there are no values at all or the statistical depth has not
		been reached. A timeout of 0 s corresponds to an infinite measurement timeout. \n
			:return: tcd_timeout: Unit: s
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TOUT?')
		return Conversions.str_to_float(response)

	def set_timeout(self, tcd_timeout: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TOUT \n
		Snippet: driver.configure.afRf.measurement.multiEval.set_timeout(tcd_timeout = 1.0) \n
		Defines a timeout for the measurement. The timer is started when the measurement is initiated via a READ or INIT command.
		It is not started if the measurement is initiated via the graphical user interface. The timer is reset after the first
		measurement cycle. If the first measurement cycle has not been completed when the timer expires, the measurement is
		stopped and the reliability indicator is set to 1. Still running READ, FETCh or CALCulate commands are completed,
		returning the available results. At least for some results, there are no values at all or the statistical depth has not
		been reached. A timeout of 0 s corresponds to an infinite measurement timeout. \n
			:param tcd_timeout: Unit: s
		"""
		param = Conversions.decimal_value_to_str(tcd_timeout)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:TOUT {param}')

	def get_sautomatic(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:SAUTomatic \n
		Snippet: value: bool = driver.configure.afRf.measurement.multiEval.get_sautomatic() \n
		No command help available \n
			:return: start_meas_automatic: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:SAUTomatic?')
		return Conversions.str_to_bool(response)

	def set_sautomatic(self, start_meas_automatic: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:SAUTomatic \n
		Snippet: driver.configure.afRf.measurement.multiEval.set_sautomatic(start_meas_automatic = False) \n
		No command help available \n
			:param start_meas_automatic: No help available
		"""
		param = Conversions.bool_to_str(start_meas_automatic)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:SAUTomatic {param}')

	def get_st_find(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:STFind \n
		Snippet: value: bool = driver.configure.afRf.measurement.multiEval.get_st_find() \n
		No command help available \n
			:return: start_find: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:STFind?')
		return Conversions.str_to_bool(response)

	def set_st_find(self, start_find: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:STFind \n
		Snippet: driver.configure.afRf.measurement.multiEval.set_st_find(start_find = False) \n
		No command help available \n
			:param start_find: No help available
		"""
		param = Conversions.bool_to_str(start_find)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:STFind {param}')

	def clone(self) -> 'MultiEval':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MultiEval(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Help:
	"""Help commands group definition. 5 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("help", core, parent)

	@property
	def headers(self):
		"""headers commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_headers'):
			from .Help_.Headers import Headers
			self._headers = Headers(self._core, self._base)
		return self._headers

	@property
	def syntax(self):
		"""syntax commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_syntax'):
			from .Help_.Syntax import Syntax
			self._syntax = Syntax(self._core, self._base)
		return self._syntax

	@property
	def status(self):
		"""status commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_status'):
			from .Help_.Status import Status
			self._status = Status(self._core, self._base)
		return self._status

	def clone(self) -> 'Help':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Help(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class New:
	"""New commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("new", core, parent)

	def set(self, current_password: str, new_password: str) -> None:
		"""SCPI: SYSTem:PASSword:NEW \n
		Snippet: driver.system.password.new.set(current_password = '1', new_password = '1') \n
		No command help available \n
			:param current_password: No help available
			:param new_password: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('current_password', current_password, DataType.String), ArgSingle('new_password', new_password, DataType.String))
		self._core.io.write(f'SYSTem:PASSword:NEW {param}'.rstrip())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.Utilities import trim_str_response
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Version:
	"""Version commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("version", core, parent)

	def get(self, applicname: str = None) -> str:
		"""SCPI: SYSTem:OPTion:VERSion \n
		Snippet: value: str = driver.system.option.version.get(applicname = '1') \n
		Returns version information for installed software packages.
			INTRO_CMD_HELP: The structure of the returned string depends on the parameter <Application>: \n
			- If <Application> is specified Returned string: '<Version>' '0' means that the application is unknown or not installed.
			- If <Application> is omitted Returned string: '<PackageName1>,<Version1>;<PackageName2>,<Version2>;...' \n
			:param applicname: No help available
			:return: option_list: No help available"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('applicname', applicname, DataType.String, True))
		response = self._core.io.query_str(f'SYSTem:OPTion:VERSion? {param}'.rstrip())
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Average:
	"""Average commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("average", core, parent)

	# noinspection PyTypeChecker
	class CalculateStruct(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Power: enums.ResultStatus: Reverse power or forward power Unit: dBm
			- Return_Loss: enums.ResultStatus: Unit: dB
			- Reflection: enums.ResultStatus: Unit: %
			- Swr: enums.ResultStatus: Standing wave ratio"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_enum('Power', enums.ResultStatus),
			ArgStruct.scalar_enum('Return_Loss', enums.ResultStatus),
			ArgStruct.scalar_enum('Reflection', enums.ResultStatus),
			ArgStruct.scalar_enum('Swr', enums.ResultStatus)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Power: enums.ResultStatus = None
			self.Return_Loss: enums.ResultStatus = None
			self.Reflection: enums.ResultStatus = None
			self.Swr: enums.ResultStatus = None

	def calculate(self) -> CalculateStruct:
		"""SCPI: CALCulate:GPRF:MEASurement<Instance>:NRT:REVerse:AVERage \n
		Snippet: value: CalculateStruct = driver.gprfMeasurement.nrt.reverse.average.calculate() \n
		Return the measurement results for the reverse direction.
			INTRO_CMD_HELP: The meaning of the result <Power> depends on the value set via the command method RsCma.Configure.GprfMeasurement.Nrt.Forward.Value.enable: \n
			- FPWR or PEP: <Power> is the reverse power.
			- CFAC or CCDF: <Power> is the forward power.
		CALCulate commands return error indicators instead of measurement values. \n
			:return: structure: for return value, see the help for CalculateStruct structure arguments."""
		return self._core.io.query_struct(f'CALCulate:GPRF:MEASurement<Instance>:NRT:REVerse:AVERage?', self.__class__.CalculateStruct())

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Power: float: Reverse power or forward power Unit: dBm
			- Return_Loss: float: Unit: dB
			- Reflection: float: Unit: %
			- Swr: float: Standing wave ratio"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Power'),
			ArgStruct.scalar_float('Return_Loss'),
			ArgStruct.scalar_float('Reflection'),
			ArgStruct.scalar_float('Swr')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Power: float = None
			self.Return_Loss: float = None
			self.Reflection: float = None
			self.Swr: float = None

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:NRT:REVerse:AVERage \n
		Snippet: value: ResultData = driver.gprfMeasurement.nrt.reverse.average.fetch() \n
		Return the measurement results for the reverse direction.
			INTRO_CMD_HELP: The meaning of the result <Power> depends on the value set via the command method RsCma.Configure.GprfMeasurement.Nrt.Forward.Value.enable: \n
			- FPWR or PEP: <Power> is the reverse power.
			- CFAC or CCDF: <Power> is the forward power.
		CALCulate commands return error indicators instead of measurement values. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:GPRF:MEASurement<Instance>:NRT:REVerse:AVERage?', self.__class__.ResultData())

	def read(self) -> ResultData:
		"""SCPI: READ:GPRF:MEASurement<Instance>:NRT:REVerse:AVERage \n
		Snippet: value: ResultData = driver.gprfMeasurement.nrt.reverse.average.read() \n
		Return the measurement results for the reverse direction.
			INTRO_CMD_HELP: The meaning of the result <Power> depends on the value set via the command method RsCma.Configure.GprfMeasurement.Nrt.Forward.Value.enable: \n
			- FPWR or PEP: <Power> is the reverse power.
			- CFAC or CCDF: <Power> is the forward power.
		CALCulate commands return error indicators instead of measurement values. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:GPRF:MEASurement<Instance>:NRT:REVerse:AVERage?', self.__class__.ResultData())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Digital:
	"""Digital commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("digital", core, parent)

	def get_file(self) -> str:
		"""SCPI: SOURce:XRT:GENerator<Instance>:DIGital:FILE \n
		Snippet: value: str = driver.source.xrt.generator.digital.get_file() \n
		No command help available \n
			:return: arb_file: No help available
		"""
		response = self._core.io.query_str_with_opc('SOURce:XRT:GENerator<Instance>:DIGital:FILE?')
		return trim_str_response(response)

	def set_file(self, arb_file: str) -> None:
		"""SCPI: SOURce:XRT:GENerator<Instance>:DIGital:FILE \n
		Snippet: driver.source.xrt.generator.digital.set_file(arb_file = '1') \n
		No command help available \n
			:param arb_file: No help available
		"""
		param = Conversions.value_to_quoted_str(arb_file)
		self._core.io.write_with_opc(f'SOURce:XRT:GENerator<Instance>:DIGital:FILE {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Modulator:
	"""Modulator commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("modulator", core, parent)

	def get_fdeviation(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IFERer:MODulator:FDEViation \n
		Snippet: value: float = driver.source.afRf.generator.interferer.modulator.get_fdeviation() \n
		Specifies the maximum frequency deviation for the FM interferer mode. \n
			:return: freq_deviation: Range: 0 Hz to 100 kHz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:IFERer:MODulator:FDEViation?')
		return Conversions.str_to_float(response)

	def set_fdeviation(self, freq_deviation: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IFERer:MODulator:FDEViation \n
		Snippet: driver.source.afRf.generator.interferer.modulator.set_fdeviation(freq_deviation = 1.0) \n
		Specifies the maximum frequency deviation for the FM interferer mode. \n
			:param freq_deviation: Range: 0 Hz to 100 kHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(freq_deviation)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IFERer:MODulator:FDEViation {param}')

	def get_pdeviation(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IFERer:MODulator:PDEViation \n
		Snippet: value: float = driver.source.afRf.generator.interferer.modulator.get_pdeviation() \n
		Specifies the maximum phase deviation for the PM interferer mode. \n
			:return: phase_deviation: Range: 0 rad to 10 rad, Unit: rad
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:IFERer:MODulator:PDEViation?')
		return Conversions.str_to_float(response)

	def set_pdeviation(self, phase_deviation: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IFERer:MODulator:PDEViation \n
		Snippet: driver.source.afRf.generator.interferer.modulator.set_pdeviation(phase_deviation = 1.0) \n
		Specifies the maximum phase deviation for the PM interferer mode. \n
			:param phase_deviation: Range: 0 rad to 10 rad, Unit: rad
		"""
		param = Conversions.decimal_value_to_str(phase_deviation)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IFERer:MODulator:PDEViation {param}')

	def get_mod_depth(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IFERer:MODulator:MDEPth \n
		Snippet: value: float = driver.source.afRf.generator.interferer.modulator.get_mod_depth() \n
		Specifies the modulation depth for the AM interferer mode. \n
			:return: modulation_depth: Range: 0 % to 100 %, Unit: %
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:IFERer:MODulator:MDEPth?')
		return Conversions.str_to_float(response)

	def set_mod_depth(self, modulation_depth: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IFERer:MODulator:MDEPth \n
		Snippet: driver.source.afRf.generator.interferer.modulator.set_mod_depth(modulation_depth = 1.0) \n
		Specifies the modulation depth for the AM interferer mode. \n
			:param modulation_depth: Range: 0 % to 100 %, Unit: %
		"""
		param = Conversions.decimal_value_to_str(modulation_depth)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IFERer:MODulator:MDEPth {param}')



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HardCopy:
	"""HardCopy commands group definition. 3 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("hardCopy", core, parent)

	@property
	def device(self):
		"""device commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_device'):
			from .HardCopy_.Device import Device
			self._device = Device(self._core, self._base)
		return self._device

	def get_data(self) -> bytes:
		"""SCPI: HCOPy:DATA \n
		Snippet: value: bytes = driver.hardCopy.get_data() \n
		Captures a screenshot and returns the result in block data format, see also 'Block data'. It is recommended to 'switch
		on' the display before sending this command, see method RsCma.System.Display.update. \n
			:return: data: Screenshot in 488.2 block data format
		"""
		response = self._core.io.query_bin_block('HCOPy:DATA?')
		return response

	def set_file(self, filename: str) -> None:
		"""SCPI: HCOPy:FILE \n
		Snippet: driver.hardCopy.set_file(filename = '1') \n
		Captures a screenshot and stores it to the specified file. It is recommended to 'switch on' the display before sending
		this command, see method RsCma.System.Display.update. \n
			:param filename: String parameter specifying the absolute path and name of the file. The file extension is added automatically according to the configured format (see method RsCma.HardCopy.Device.formatPy) .
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'HCOPy:FILE {param}')

	def clone(self) -> 'HardCopy':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HardCopy(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
